CretaDeviceWatchWidget class
디지털 시계를 표시하는 위젯입니다.
이 위젯이 올바르게 작동하려면 ProviderScope로 감싸야 합니다.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- CretaDeviceWatchWidget
Constructors
-
CretaDeviceWatchWidget({Key? key, List<
String> alarmTimes = const [], double width = 1920, bool showBorder = false, bool useOnlyWatch = false, bool showMenuButtons = true, bool darkMode = true, bool flipScreen = false, bool showSec = true, Color bgColor = Colors.transparent, Color fgColor = Colors.white, Color watchBgColor = Colors.black, bool showDate = true}) -
const
Properties
-
alarmTimes
→ List<
String> -
final
- bgColor → Color
-
final
- darkMode → bool
-
final
- fgColor → Color
-
final
- flipScreen → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showBorder → bool
-
final
- showDate → bool
-
final
- showMenuButtons → bool
-
final
- showSec → bool
-
final
- useOnlyWatch → bool
-
final
- watchBgColor → Color
-
final
- width → double
-
final
Methods
-
createElement(
) → ConsumerStatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → ConsumerState< CretaDeviceWatchWidget> - Creates the mutable state for this widget at a given location in the tree.
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited