ClockSettings class
- Annotations
Constructors
- ClockSettings({ThemeMode themeMode = ThemeMode.dark, TimeFormat timeFormat = TimeFormat.h24, bool isFlipped = false, bool isWeatherEnabled = true})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isFlipped → bool
-
final
- isWeatherEnabled → bool
-
final
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited - themeMode → ThemeMode
-
final
- timeFormat → TimeFormat
-
final
Methods
-
copyWith(
{ThemeMode? themeMode, TimeFormat? timeFormat, bool? isFlipped, bool? isWeatherEnabled}) → ClockSettings -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited