GetTimeStream class

Constructors

GetTimeStream(TimeRepository repository)

Properties

hashCode int
The hash code for this object.
no setterinherited
repository TimeRepository
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

call() Stream<DateTime>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited