SettingsDataSourceImpl class

Implemented types

Constructors

SettingsDataSourceImpl(SharedPreferences sharedPreferences)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sharedPreferences → SharedPreferences
final

Methods

getSettings() Future<ClockSettings>
override
getThemeMode() Future<String?>
override
getTimeFormat() Future<String?>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
saveSettings(ClockSettings settings) Future<void>
override
setThemeMode(String themeMode) Future<void>
override
setTimeFormat(String timeFormat) Future<void>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited