SettingsNotifier class
- Inheritance
-
- Object
- StateNotifier<
ClockSettings> - SettingsNotifier
Constructors
- SettingsNotifier(GetSettings _getSettings, SaveSettings _saveSettings)
Properties
- debugState → ClockSettings
-
A development-only way to access
stateoutside ofStateNotifier.no setterinherited - hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
If a listener has been added using
addListenerand hasn't been removed yet.no setterinherited - mounted → bool
-
Whether
disposewas called or not.no setterinherited - onError ↔ ErrorListener?
-
A callback for error reporting if one of the listeners added with
addListenerthrows.getter/setter pairinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state ↔ ClockSettings
-
The current "state" of this
StateNotifier.getter/setter pairinherited -
stream
→ Stream<
ClockSettings> -
A broadcast stream representation of a
StateNotifier.no setterinherited
Methods
-
addListener(
Listener< ClockSettings> listener, {bool fireImmediately = true}) → RemoveListener -
Subscribes to this object.
inherited
-
dispose(
) → void -
Frees all the resources associated with this object.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toggleFlipped(
) → Future< void> -
toggleWeatherFeature(
) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
-
updateShouldNotify(
ClockSettings old, ClockSettings current) → bool -
Whether to notify listeners or not when
statechangesinherited -
updateThemeMode(
ThemeMode newThemeMode) → Future< void> -
updateTimeFormat(
TimeFormat newTimeFormat) → Future< void>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited