WeatherModel class

Inheritance

Constructors

WeatherModel({required String cityName, required double temperature, required double tempMin, required double tempMax, required String condition, required String description, required String icon, required double windSpeed, required int windDirection, required int humidity, required int pressure, required int clouds, required DateTime lastUpdated, double? rainVolume, double? snowVolume})
const
WeatherModel.fromJson(Map<String, dynamic> json)
factory

Properties

cityName String
finalinherited
clouds int
finalinherited
condition String
finalinherited
description String
finalinherited
hashCode int
The hash code for this object.
no setterinherited
humidity int
finalinherited
icon String
finalinherited
lastUpdated DateTime
finalinherited
pressure int
finalinherited
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setterinherited
rainVolume double?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
snowVolume double?
finalinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
temperature double
finalinherited
tempMax double
finalinherited
tempMin double
finalinherited
windDirection int
finalinherited
windSpeed double
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited