WeatherState class
Constructors
- WeatherState({bool isLoading = false, Weather? weather, String? error})
-
const
- WeatherState.initial()
-
factory
Properties
- error → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isLoading → bool
-
final
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited - weather → Weather?
-
final
Methods
-
copyWith(
{bool? isLoading, Weather? weather, String? error}) → WeatherState -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited