MainClockView class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- MainClockView
Constructors
-
MainClockView({Key? key, required double width, required double height, bool isAlarmRinging = false, required VoidCallback onDismissAlarm, required VoidCallback onShowRsi, List<
String> ? alarmTimes, required dynamic onAddAlarm(DateTime), required dynamic onDeleteAlarm(int), bool useOnlyWatch = false, bool showMenuButtons = true, double scale = 1.0, bool showSec = true, Color fgColor = Colors.white, Color watchBgColor = Colors.black, bool showDate = true}) -
const
Properties
-
alarmTimes
→ List<
String> ? -
final
- fgColor → Color
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double
-
final
- isAlarmRinging → bool
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- onAddAlarm → dynamic Function(DateTime)
-
final
- onDeleteAlarm → dynamic Function(int)
-
final
- onDismissAlarm → VoidCallback
-
final
- onShowRsi → VoidCallback
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scale → double
-
final
- showDate → bool
-
final
- showMenuButtons → bool
-
final
- showSec → bool
-
final
- useOnlyWatch → bool
-
final
- watchBgColor → Color
-
final
- width → double
-
final
Methods
-
build(
BuildContext context, WidgetRef ref) → Widget - Describes the part of the user interface represented by this widget.
-
createElement(
) → ConsumerStatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → _ConsumerState -
Creates the mutable state for this widget at a given location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited